.. note::

    When viewing an Nilearn estimator in a notebook
    (or more generally on an HTML page like here)
    you get an expandable 'Parameters' section
    where the parameters that have different values from their default
    are highlighted in orange.
    If you are using a version of scikit-learn >= 1.8.0
    you will also get access to the 'docstring' description of each parameter.
